summaryrefslogtreecommitdiff
path: root/arch/arm/mach-tegra/tegra2_dvfs.c
diff options
context:
space:
mode:
authorJay Cheng <jacheng@nvidia.com>2011-12-08 09:45:25 -0500
committerVarun Wadekar <vwadekar@nvidia.com>2011-12-15 13:56:28 +0530
commitda35eccad3b9b6bac28065a36f9ce20dbe136764 (patch)
treebfbe6726ed8d8f2459a72db7d5d891b2db2ff838 /arch/arm/mach-tegra/tegra2_dvfs.c
parent0dc01f93873b8d3e6b4b5ca175035fe61121ddde (diff)
tegra2: dvfs:vdd_core voltage must be 120mv higher than vdd_cpu
bug 880495 Change-Id: Ic89487c6296b20377ee12a135d06bef5b5c8b6fa Reviewed-on: http://git-master/r/68983 Reviewed-by: Automatic_Commit_Validation_User Reviewed-by: Varun Colbert <vcolbert@nvidia.com> Tested-by: Varun Colbert <vcolbert@nvidia.com>
Diffstat (limited to 'arch/arm/mach-tegra/tegra2_dvfs.c')
-rw-r--r--arch/arm/mach-tegra/tegra2_dvfs.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/arch/arm/mach-tegra/tegra2_dvfs.c b/arch/arm/mach-tegra/tegra2_dvfs.c
index 7ab1f733add7..a864184140e6 100644
--- a/arch/arm/mach-tegra/tegra2_dvfs.c
+++ b/arch/arm/mach-tegra/tegra2_dvfs.c
@@ -80,16 +80,16 @@ static struct dvfs_rail tegra2_dvfs_rail_vdd_aon = {
#endif
};
/* vdd_core and vdd_aon must be 50 mV higher than vdd_cpu */
static int tegra2_dvfs_rel_vdd_cpu_vdd_core(struct dvfs_rail *vdd_cpu,
struct dvfs_rail *vdd_core)
{
if (vdd_cpu->new_millivolts > vdd_cpu->millivolts &&
- vdd_core->new_millivolts < vdd_cpu->new_millivolts + 50)
- return vdd_cpu->new_millivolts + 50;
+ vdd_core->new_millivolts < vdd_cpu->new_millivolts + 120)
+ return vdd_cpu->new_millivolts + 120;
- if (vdd_core->new_millivolts < vdd_cpu->millivolts + 50)
- return vdd_cpu->millivolts + 50;
+ if (vdd_core->new_millivolts < vdd_cpu->millivolts + 120)
+ return vdd_cpu->millivolts + 120;
return vdd_core->new_millivolts;
}
@@ -105,13 +105,13 @@ static int tegra2_dvfs_rel_vdd_core_vdd_aon(struct dvfs_rail *vdd_core,
static struct dvfs_relationship tegra2_dvfs_relationships[] = {
{
/* vdd_core must be 50 mV higher than vdd_cpu */
.from = &tegra2_dvfs_rail_vdd_cpu,
.to = &tegra2_dvfs_rail_vdd_core,
.solve = tegra2_dvfs_rel_vdd_cpu_vdd_core,
},
{
/* vdd_aon must be 50 mV higher than vdd_cpu */
.from = &tegra2_dvfs_rail_vdd_cpu,
.to = &tegra2_dvfs_rail_vdd_aon,
.solve = tegra2_dvfs_rel_vdd_cpu_vdd_core,
@@ -80,16 +80,16 @@ static struct dvfs_rail tegra2_dvfs_rail_vdd_aon = {
#endif
};
-/* vdd_core and vdd_aon must be 50 mV higher than vdd_cpu */
+/* vdd_core and vdd_aon must be 120 mV higher than vdd_cpu */
static int tegra2_dvfs_rel_vdd_cpu_vdd_core(struct dvfs_rail *vdd_cpu,
struct dvfs_rail *vdd_core)
@@ -105,13 +105,13 @@ static int tegra2_dvfs_rel_vdd_core_vdd_aon(struct dvfs_rail *vdd_core,
static struct dvfs_relationship tegra2_dvfs_relationships[] = {
{
- /* vdd_core must be 50 mV higher than vdd_cpu */
+ /* vdd_core must be 120 mV higher than vdd_cpu */
.from = &tegra2_dvfs_rail_vdd_cpu,
.to = &tegra2_dvfs_rail_vdd_core,
@@ -105,13 +105,13 @@ static int tegra2_dvfs_rel_vdd_core_vdd_aon(struct dvfs_rail *vdd_core,
},
{
- /* vdd_aon must be 50 mV higher than vdd_cpu */
+ /* vdd_aon must be 120 mV higher than vdd_cpu */
.from = &tegra2_dvfs_rail_vdd_cpu,
.to = &tegra2_dvfs_rail_vdd_aon,